OiRA

Help

1. Priprema
2. Uključite
3. Procjena
4. Završni dokumenti
5. Status 92%

# Status $ Private Security, Grafton Street

## Opće informacije

Korišteni alat

  Private Security, Grafton Street

## Certification

### 92% Complete

92% Complete! You've earned a certificate for this tool.

With this certificate, you can apply for a reduction on your company's insurance rates. Learn more about the benefits…

View certificate

## Odgovorena pitanja po modulu

Commercial manned guarding - Abby Road

  1 question answered without a risk

  3 answers indicated a risk and have at least one measure defined in the action plan

  2 answers indicated a risk without any measure defined in the action plan

  2 questions were postponed

  2 questions aren't answered yet

  - 1 Rizik ne postoji
  - 3
  - 2 Postoji rizik
  - 2 Odgođen
  - 2 Neodgovoren

  #### Rizici visokog prioriteta

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis
Mobile partrolling/intervention after alarm

  7 Neodgovoren

  1

  1 Postoji rizik

  1 Odgođen

  - 7 Neodgovoren
  - 1
  - 1 Postoji rizik
  - 1 Odgođen

  #### High priority risks

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis

Scroll to top
Back

## status-certificate.html

Više

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More